@@ -1,8 +1,7 @@
 import socket
+from dataclasses import dataclass
 from typing import Union
 
-import attr
-
 
 def free_port() -> int:
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
@@ -23,9 +22,9 @@ def px_to_number(value: str) -> Union[int, float]:
         raise ValueError(f"{original!r} is not an number or <number>px value")
 
 
-@attr.s
+@dataclass
 class Rect:
-    x: float = attr.ib()
-    y: float = attr.ib()
-    width: float = attr.ib()
-    height: float = attr.ib()
+    x: float
+    y: float
+    width: float
+    height: float
